# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/node_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.k8s.v1 import maintenance_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_maintenance__pb2
from yandex.cloud.k8s.v1 import node_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2
from yandex.cloud.k8s.v1 import version_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/k8s/v1/node_group.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%yandex/cloud/k8s/v1/maintenance.proto\x1a\x1eyandex/cloud/k8s/v1/node.proto\x1a!yandex/cloud/k8s/v1/version.proto\x1a\x1dyandex/cloud/validation.proto\"\xa0\x08\n\tNodeGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12:\n\x06labels\x18\x06 \x03(\x0b\x32*.yandex.cloud.k8s.v1.NodeGroup.LabelsEntry\x12\x35\n\x06status\x18\x07 \x01(\x0e\x32%.yandex.cloud.k8s.v1.NodeGroup.Status\x12\x38\n\rnode_template\x18\x08 \x01(\x0b\x32!.yandex.cloud.k8s.v1.NodeTemplate\x12\x36\n\x0cscale_policy\x18\t \x01(\x0b\x32 .yandex.cloud.k8s.v1.ScalePolicy\x12I\n\x11\x61llocation_policy\x18\n \x01(\x0b\x32..yandex.cloud.k8s.v1.NodeGroupAllocationPolicy\x12\x38\n\rdeploy_policy\x18\x12 \x01(\x0b\x32!.yandex.cloud.k8s.v1.DeployPolicy\x12\x19\n\x11instance_group_id\x18\x0b \x01(\t\x12\x14\n\x0cnode_version\x18\x0c \x01(\t\x12\x36\n\x0cversion_info\x18\r \x01(\x0b\x32 .yandex.cloud.k8s.v1.VersionInfo\x12K\n\x12maintenance_policy\x18\x0e \x01(\x0b\x32/.yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy\x12\x1e\n\x16\x61llowed_unsafe_sysctls\x18\x0f \x03(\t\x12/\n\x0bnode_taints\x18\x10 \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12\x43\n\x0bnode_labels\x18\x11 \x03(\x0b\x32..yandex.cloud.k8s.v1.NodeGroup.NodeLabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0f\n\x0bRECONCILING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"\xb6\x02\n\x0bScalePolicy\x12\x42\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32+.yandex.cloud.k8s.v1.ScalePolicy.FixedScaleH\x00\x12@\n\nauto_scale\x18\x02 \x01(\x0b\x32*.yandex.cloud.k8s.v1.ScalePolicy.AutoScaleH\x00\x1a%\n\nFixedScale\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x1a\x66\n\tAutoScale\x12\x1b\n\x08min_size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1b\n\x08max_size\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1f\n\x0cinitial_size\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100B\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\"V\n\x19NodeGroupAllocationPolicy\x12\x39\n\tlocations\x18\x01 \x03(\x0b\x32&.yandex.cloud.k8s.v1.NodeGroupLocation\"=\n\x11NodeGroupLocation\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"\x8b\x01\n\x1aNodeGroupMaintenancePolicy\x12\x14\n\x0c\x61uto_upgrade\x18\x01 \x01(\x08\x12\x13\n\x0b\x61uto_repair\x18\x02 \x01(\x08\x12\x42\n\x12maintenance_window\x18\x03 \x01(\x0b\x32&.yandex.cloud.k8s.v1.MaintenanceWindow\"T\n\x0c\x44\x65ployPolicy\x12\"\n\x0fmax_unavailable\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12 \n\rmax_expansion\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100BV\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.v1.node_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s'
  _NODEGROUP_LABELSENTRY._options = None
  _NODEGROUP_LABELSENTRY._serialized_options = b'8\001'
  _NODEGROUP_NODELABELSENTRY._options = None
  _NODEGROUP_NODELABELSENTRY._serialized_options = b'8\001'
  _SCALEPOLICY_FIXEDSCALE.fields_by_name['size']._options = None
  _SCALEPOLICY_FIXEDSCALE.fields_by_name['size']._serialized_options = b'\372\3071\0050-100'
  _SCALEPOLICY_AUTOSCALE.fields_by_name['min_size']._options = None
  _SCALEPOLICY_AUTOSCALE.fields_by_name['min_size']._serialized_options = b'\372\3071\0050-100'
  _SCALEPOLICY_AUTOSCALE.fields_by_name['max_size']._options = None
  _SCALEPOLICY_AUTOSCALE.fields_by_name['max_size']._serialized_options = b'\372\3071\0050-100'
  _SCALEPOLICY_AUTOSCALE.fields_by_name['initial_size']._options = None
  _SCALEPOLICY_AUTOSCALE.fields_by_name['initial_size']._serialized_options = b'\372\3071\0050-100'
  _SCALEPOLICY.oneofs_by_name['scale_type']._options = None
  _SCALEPOLICY.oneofs_by_name['scale_type']._serialized_options = b'\300\3011\001'
  _NODEGROUPLOCATION.fields_by_name['zone_id']._options = None
  _NODEGROUPLOCATION.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _DEPLOYPOLICY.fields_by_name['max_unavailable']._options = None
  _DEPLOYPOLICY.fields_by_name['max_unavailable']._serialized_options = b'\372\3071\0050-100'
  _DEPLOYPOLICY.fields_by_name['max_expansion']._options = None
  _DEPLOYPOLICY.fields_by_name['max_expansion']._serialized_options = b'\372\3071\0050-100'
  _globals['_NODEGROUP']._serialized_start=232
  _globals['_NODEGROUP']._serialized_end=1288
  _globals['_NODEGROUP_LABELSENTRY']._serialized_start=1054
  _globals['_NODEGROUP_LABELSENTRY']._serialized_end=1099
  _globals['_NODEGROUP_NODELABELSENTRY']._serialized_start=1101
  _globals['_NODEGROUP_NODELABELSENTRY']._serialized_end=1150
  _globals['_NODEGROUP_STATUS']._serialized_start=1153
  _globals['_NODEGROUP_STATUS']._serialized_end=1288
  _globals['_SCALEPOLICY']._serialized_start=1291
  _globals['_SCALEPOLICY']._serialized_end=1601
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_start=1440
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_end=1477
  _globals['_SCALEPOLICY_AUTOSCALE']._serialized_start=1479
  _globals['_SCALEPOLICY_AUTOSCALE']._serialized_end=1581
  _globals['_NODEGROUPALLOCATIONPOLICY']._serialized_start=1603
  _globals['_NODEGROUPALLOCATIONPOLICY']._serialized_end=1689
  _globals['_NODEGROUPLOCATION']._serialized_start=1691
  _globals['_NODEGROUPLOCATION']._serialized_end=1752
  _globals['_NODEGROUPMAINTENANCEPOLICY']._serialized_start=1755
  _globals['_NODEGROUPMAINTENANCEPOLICY']._serialized_end=1894
  _globals['_DEPLOYPOLICY']._serialized_start=1896
  _globals['_DEPLOYPOLICY']._serialized_end=1980
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/triggers/v1/trigger_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.serverless.triggers.v1 import trigger_pb2 as yandex_dot_cloud_dot_serverless_dot_triggers_dot_v1_dot_trigger__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/serverless/triggers/v1/trigger_service.proto\x12#yandex.cloud.serverless.triggers.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x31yandex/cloud/serverless/triggers/v1/trigger.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"-\n\x11GetTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"e\n\x13ListTriggersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"o\n\x14ListTriggersResponse\x12>\n\x08triggers\x18\x01 \x03(\x0b\x32,.yandex.cloud.serverless.triggers.v1.Trigger\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8b\x03\n\x14\x43reateTriggerRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x92\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x45.yandex.cloud.serverless.triggers.v1.CreateTriggerRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x45\n\x04rule\x18\x05 \x01(\x0b\x32\x31.yandex.cloud.serverless.triggers.v1.Trigger.RuleB\x04\xe8\xc7\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateTriggerMetadata\x12\x12\n\ntrigger_id\x18\x01 \x01(\t\"\xb7\x03\n\x14UpdateTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x92\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x45.yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12?\n\x04rule\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.serverless.triggers.v1.Trigger.Rule\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x15UpdateTriggerMetadata\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"0\n\x14\x44\x65leteTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"1\n\x15\x44\x65leteTriggerMetadata\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x13PauseTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"0\n\x14PauseTriggerMetadata\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"0\n\x14ResumeTriggerRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"1\n\x15ResumeTriggerMetadata\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x92\x01\n\x1cListTriggerOperationsRequest\x12\x18\n\ntrigger_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"o\n\x1dListTriggerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xcc\x0b\n\x0eTriggerService\x12\x97\x01\n\x03Get\x12\x36.yandex.cloud.serverless.triggers.v1.GetTriggerRequest\x1a,.yandex.cloud.serverless.triggers.v1.Trigger\"*\x82\xd3\xe4\x93\x02$\x12\"/triggers/v1/triggers/{trigger_id}\x12\x9a\x01\n\x04List\x12\x38.yandex.cloud.serverless.triggers.v1.ListTriggersRequest\x1a\x39.yandex.cloud.serverless.triggers.v1.ListTriggersResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/triggers/v1/triggers\x12\xac\x01\n\x06\x43reate\x12\x39.yandex.cloud.serverless.triggers.v1.CreateTriggerRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2* \n\x15\x43reateTriggerMetadata\x12\x07Trigger\x82\xd3\xe4\x93\x02\x1a\"\x15/triggers/v1/triggers:\x01*\x12\xb9\x01\n\x06Update\x12\x39.yandex.cloud.serverless.triggers.v1.UpdateTriggerRequest\x1a!.yandex.cloud.operation.Operation\"Q\xb2\xd2* \n\x15UpdateTriggerMetadata\x12\x07Trigger\x82\xd3\xe4\x93\x02\'2\"/triggers/v1/triggers/{trigger_id}:\x01*\x12\xc4\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.serverless.triggers.v1.DeleteTriggerRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*.\n\x15\x44\x65leteTriggerMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$*\"/triggers/v1/triggers/{trigger_id}\x12\xbc\x01\n\x05Pause\x12\x38.yandex.cloud.serverless.triggers.v1.PauseTriggerRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1f\n\x14PauseTriggerMetadata\x12\x07Trigger\x82\xd3\xe4\x93\x02-\"(/triggers/v1/triggers/{trigger_id}:pause:\x01*\x12\xc0\x01\n\x06Resume\x12\x39.yandex.cloud.serverless.triggers.v1.ResumeTriggerRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2* \n\x15ResumeTriggerMetadata\x12\x07Trigger\x82\xd3\xe4\x93\x02.\")/triggers/v1/triggers/{trigger_id}:resume:\x01*\x12\xce\x01\n\x0eListOperations\x12\x41.yandex.cloud.serverless.triggers.v1.ListTriggerOperationsRequest\x1a\x42.yandex.cloud.serverless.triggers.v1.ListTriggerOperationsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/triggers/v1/triggers/{trigger_id}/operationsB{\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.triggers.v1.trigger_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggers'
  _GETTRIGGERREQUEST.fields_by_name['trigger_id']._options = None
  _GETTRIGGERREQUEST.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _LISTTRIGGERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTTRIGGERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATETRIGGERREQUEST_LABELSENTRY._options = None
  _CREATETRIGGERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATETRIGGERREQUEST.fields_by_name['folder_id']._options = None
  _CREATETRIGGERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATETRIGGERREQUEST.fields_by_name['name']._options = None
  _CREATETRIGGERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATETRIGGERREQUEST.fields_by_name['description']._options = None
  _CREATETRIGGERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATETRIGGERREQUEST.fields_by_name['labels']._options = None
  _CREATETRIGGERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATETRIGGERREQUEST.fields_by_name['rule']._options = None
  _CREATETRIGGERREQUEST.fields_by_name['rule']._serialized_options = b'\350\3071\001'
  _UPDATETRIGGERREQUEST_LABELSENTRY._options = None
  _UPDATETRIGGERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATETRIGGERREQUEST.fields_by_name['trigger_id']._options = None
  _UPDATETRIGGERREQUEST.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _UPDATETRIGGERREQUEST.fields_by_name['name']._options = None
  _UPDATETRIGGERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATETRIGGERREQUEST.fields_by_name['description']._options = None
  _UPDATETRIGGERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATETRIGGERREQUEST.fields_by_name['labels']._options = None
  _UPDATETRIGGERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATETRIGGERMETADATA.fields_by_name['trigger_id']._options = None
  _UPDATETRIGGERMETADATA.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _DELETETRIGGERREQUEST.fields_by_name['trigger_id']._options = None
  _DELETETRIGGERREQUEST.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _DELETETRIGGERMETADATA.fields_by_name['trigger_id']._options = None
  _DELETETRIGGERMETADATA.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _PAUSETRIGGERREQUEST.fields_by_name['trigger_id']._options = None
  _PAUSETRIGGERREQUEST.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _PAUSETRIGGERMETADATA.fields_by_name['trigger_id']._options = None
  _PAUSETRIGGERMETADATA.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _RESUMETRIGGERREQUEST.fields_by_name['trigger_id']._options = None
  _RESUMETRIGGERREQUEST.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _RESUMETRIGGERMETADATA.fields_by_name['trigger_id']._options = None
  _RESUMETRIGGERMETADATA.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _LISTTRIGGEROPERATIONSREQUEST.fields_by_name['trigger_id']._options = None
  _LISTTRIGGEROPERATIONSREQUEST.fields_by_name['trigger_id']._serialized_options = b'\350\3071\001'
  _LISTTRIGGEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTTRIGGEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTTRIGGEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTTRIGGEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTTRIGGEROPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTTRIGGEROPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _TRIGGERSERVICE.methods_by_name['Get']._options = None
  _TRIGGERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002$\022\"/triggers/v1/triggers/{trigger_id}'
  _TRIGGERSERVICE.methods_by_name['List']._options = None
  _TRIGGERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/triggers/v1/triggers'
  _TRIGGERSERVICE.methods_by_name['Create']._options = None
  _TRIGGERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateTriggerMetadata\022\007Trigger\202\323\344\223\002\032\"\025/triggers/v1/triggers:\001*'
  _TRIGGERSERVICE.methods_by_name['Update']._options = None
  _TRIGGERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateTriggerMetadata\022\007Trigger\202\323\344\223\002\'2\"/triggers/v1/triggers/{trigger_id}:\001*'
  _TRIGGERSERVICE.methods_by_name['Delete']._options = None
  _TRIGGERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteTriggerMetadata\022\025google.protobuf.Empty\202\323\344\223\002$*\"/triggers/v1/triggers/{trigger_id}'
  _TRIGGERSERVICE.methods_by_name['Pause']._options = None
  _TRIGGERSERVICE.methods_by_name['Pause']._serialized_options = b'\262\322*\037\n\024PauseTriggerMetadata\022\007Trigger\202\323\344\223\002-\"(/triggers/v1/triggers/{trigger_id}:pause:\001*'
  _TRIGGERSERVICE.methods_by_name['Resume']._options = None
  _TRIGGERSERVICE.methods_by_name['Resume']._serialized_options = b'\262\322* \n\025ResumeTriggerMetadata\022\007Trigger\202\323\344\223\002.\")/triggers/v1/triggers/{trigger_id}:resume:\001*'
  _TRIGGERSERVICE.methods_by_name['ListOperations']._options = None
  _TRIGGERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002/\022-/triggers/v1/triggers/{trigger_id}/operations'
  _globals['_GETTRIGGERREQUEST']._serialized_start=318
  _globals['_GETTRIGGERREQUEST']._serialized_end=363
  _globals['_LISTTRIGGERSREQUEST']._serialized_start=365
  _globals['_LISTTRIGGERSREQUEST']._serialized_end=466
  _globals['_LISTTRIGGERSRESPONSE']._serialized_start=468
  _globals['_LISTTRIGGERSRESPONSE']._serialized_end=579
  _globals['_CREATETRIGGERREQUEST']._serialized_start=582
  _globals['_CREATETRIGGERREQUEST']._serialized_end=977
  _globals['_CREATETRIGGERREQUEST_LABELSENTRY']._serialized_start=932
  _globals['_CREATETRIGGERREQUEST_LABELSENTRY']._serialized_end=977
  _globals['_CREATETRIGGERMETADATA']._serialized_start=979
  _globals['_CREATETRIGGERMETADATA']._serialized_end=1022
  _globals['_UPDATETRIGGERREQUEST']._serialized_start=1025
  _globals['_UPDATETRIGGERREQUEST']._serialized_end=1464
  _globals['_UPDATETRIGGERREQUEST_LABELSENTRY']._serialized_start=932
  _globals['_UPDATETRIGGERREQUEST_LABELSENTRY']._serialized_end=977
  _globals['_UPDATETRIGGERMETADATA']._serialized_start=1466
  _globals['_UPDATETRIGGERMETADATA']._serialized_end=1515
  _globals['_DELETETRIGGERREQUEST']._serialized_start=1517
  _globals['_DELETETRIGGERREQUEST']._serialized_end=1565
  _globals['_DELETETRIGGERMETADATA']._serialized_start=1567
  _globals['_DELETETRIGGERMETADATA']._serialized_end=1616
  _globals['_PAUSETRIGGERREQUEST']._serialized_start=1618
  _globals['_PAUSETRIGGERREQUEST']._serialized_end=1665
  _globals['_PAUSETRIGGERMETADATA']._serialized_start=1667
  _globals['_PAUSETRIGGERMETADATA']._serialized_end=1715
  _globals['_RESUMETRIGGERREQUEST']._serialized_start=1717
  _globals['_RESUMETRIGGERREQUEST']._serialized_end=1765
  _globals['_RESUMETRIGGERMETADATA']._serialized_start=1767
  _globals['_RESUMETRIGGERMETADATA']._serialized_end=1816
  _globals['_LISTTRIGGEROPERATIONSREQUEST']._serialized_start=1819
  _globals['_LISTTRIGGEROPERATIONSREQUEST']._serialized_end=1965
  _globals['_LISTTRIGGEROPERATIONSRESPONSE']._serialized_start=1967
  _globals['_LISTTRIGGEROPERATIONSRESPONSE']._serialized_end=2078
  _globals['_TRIGGERSERVICE']._serialized_start=2081
  _globals['_TRIGGERSERVICE']._serialized_end=3565
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/origin_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.cdn.v1 import origin_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/cdn/v1/origin_group.proto\x12\x13yandex.cloud.cdn.v1\x1a yandex/cloud/cdn/v1/origin.proto\"z\n\x0bOriginGroup\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08use_next\x18\x04 \x01(\x08\x12,\n\x07origins\x18\x05 \x03(\x0b\x32\x1b.yandex.cloud.cdn.v1.OriginBV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.origin_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_ORIGINGROUP']._serialized_start=97
  _globals['_ORIGINGROUP']._serialized_end=219
# @@protoc_insertion_point(module_scope)



from yandexcloud._wrappers.dataproc import Dataproc, InitializationAction


class Wrappers(object):
    def __init__(self, sdk):
        self.Dataproc = Dataproc
        self.Dataproc.sdk = sdk
        self.InitializationAction = InitializationAction



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/agent/create_compute_instance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.compute.v1 import instance_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCyandex/cloud/loadtesting/api/v1/agent/create_compute_instance.proto\x12%yandex.cloud.loadtesting.api.v1.agent\x1a.yandex/cloud/compute/v1/instance_service.proto\x1a\x1dyandex/cloud/validation.proto\"\xbd\x05\n\x15\x43reateComputeInstance\x12\x9d\x01\n\x06labels\x18\x04 \x03(\x0b\x32H.yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x1d\n\x07zone_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x44\n\x0eresources_spec\x18\x07 \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpecB\x04\xe8\xc7\x31\x01\x12\\\n\x08metadata\x18\x08 \x03(\x0b\x32J.yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance.MetadataEntry\x12G\n\x0e\x62oot_disk_spec\x18\t \x01(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\x12U\n\x17network_interface_specs\x18\x0b \x03(\x0b\x32-.yandex.cloud.compute.v1.NetworkInterfaceSpecB\x05\x82\xc8\x31\x01\x31\x12\x1a\n\x12service_account_id\x18\x0e \x01(\t\x12\x13\n\x0bplatform_id\x18\x0f \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\n\x10\x0bJ\x04\x08\x0c\x10\x0eJ\x04\x08\x06\x10\x07\x42|\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.agent.create_compute_instance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agent'
  _CREATECOMPUTEINSTANCE_LABELSENTRY._options = None
  _CREATECOMPUTEINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _CREATECOMPUTEINSTANCE_METADATAENTRY._options = None
  _CREATECOMPUTEINSTANCE_METADATAENTRY._serialized_options = b'8\001'
  _CREATECOMPUTEINSTANCE.fields_by_name['labels']._options = None
  _CREATECOMPUTEINSTANCE.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATECOMPUTEINSTANCE.fields_by_name['zone_id']._options = None
  _CREATECOMPUTEINSTANCE.fields_by_name['zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECOMPUTEINSTANCE.fields_by_name['resources_spec']._options = None
  _CREATECOMPUTEINSTANCE.fields_by_name['resources_spec']._serialized_options = b'\350\3071\001'
  _CREATECOMPUTEINSTANCE.fields_by_name['boot_disk_spec']._options = None
  _CREATECOMPUTEINSTANCE.fields_by_name['boot_disk_spec']._serialized_options = b'\350\3071\001'
  _CREATECOMPUTEINSTANCE.fields_by_name['network_interface_specs']._options = None
  _CREATECOMPUTEINSTANCE.fields_by_name['network_interface_specs']._serialized_options = b'\202\3101\0011'
  _globals['_CREATECOMPUTEINSTANCE']._serialized_start=190
  _globals['_CREATECOMPUTEINSTANCE']._serialized_end=891
  _globals['_CREATECOMPUTEINSTANCE_LABELSENTRY']._serialized_start=779
  _globals['_CREATECOMPUTEINSTANCE_LABELSENTRY']._serialized_end=824
  _globals['_CREATECOMPUTEINSTANCE_METADATAENTRY']._serialized_start=826
  _globals['_CREATECOMPUTEINSTANCE_METADATAENTRY']._serialized_end=873
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/talk_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.speechsense.v1 import audio_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_audio__pb2
from yandex.cloud.speechsense.v1 import text_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_text__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/speechsense/v1/talk_service.proto\x12\x1byandex.cloud.speechsense.v1\x1a\'yandex/cloud/speechsense/v1/audio.proto\x1a&yandex/cloud/speechsense/v1/text.proto\"\xa0\x01\n\x11StreamTalkRequest\x12=\n\x08metadata\x18\x01 \x01(\x0b\x32).yandex.cloud.speechsense.v1.TalkMetadataH\x00\x12\x43\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.speechsense.v1.AudioStreamingRequestH\x00\x42\x07\n\x05\x45vent\"\x8a\x01\n\x11UploadTalkRequest\x12;\n\x08metadata\x18\x01 \x01(\x0b\x32).yandex.cloud.speechsense.v1.TalkMetadata\x12\x38\n\x05\x61udio\x18\x02 \x01(\x0b\x32).yandex.cloud.speechsense.v1.AudioRequest\"%\n\x12UploadTalkResponse\x12\x0f\n\x07talk_id\x18\x01 \x01(\t\"\x90\x01\n\x11UploadTextRequest\x12;\n\x08metadata\x18\x01 \x01(\x0b\x32).yandex.cloud.speechsense.v1.TalkMetadata\x12>\n\x0ctext_content\x18\x02 \x01(\x0b\x32(.yandex.cloud.speechsense.v1.TextContent\"%\n\x12UploadTextResponse\x12\x0f\n\x07talk_id\x18\x01 \x01(\t\"\x9b\x01\n\x0cTalkMetadata\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x45\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x35.yandex.cloud.speechsense.v1.TalkMetadata.FieldsEntry\x1a-\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\xdc\x02\n\x0bTalkService\x12s\n\x0eUploadAsStream\x12..yandex.cloud.speechsense.v1.StreamTalkRequest\x1a/.yandex.cloud.speechsense.v1.UploadTalkResponse(\x01\x12i\n\x06Upload\x12..yandex.cloud.speechsense.v1.UploadTalkRequest\x1a/.yandex.cloud.speechsense.v1.UploadTalkResponse\x12m\n\nUploadText\x12..yandex.cloud.speechsense.v1.UploadTextRequest\x1a/.yandex.cloud.speechsense.v1.UploadTextResponseBy\n\x1fyandex.cloud.api.speechsense.v1B\tTalkProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.talk_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\tTalkProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _TALKMETADATA_FIELDSENTRY._options = None
  _TALKMETADATA_FIELDSENTRY._serialized_options = b'8\001'
  _globals['_STREAMTALKREQUEST']._serialized_start=161
  _globals['_STREAMTALKREQUEST']._serialized_end=321
  _globals['_UPLOADTALKREQUEST']._serialized_start=324
  _globals['_UPLOADTALKREQUEST']._serialized_end=462
  _globals['_UPLOADTALKRESPONSE']._serialized_start=464
  _globals['_UPLOADTALKRESPONSE']._serialized_end=501
  _globals['_UPLOADTEXTREQUEST']._serialized_start=504
  _globals['_UPLOADTEXTREQUEST']._serialized_end=648
  _globals['_UPLOADTEXTRESPONSE']._serialized_start=650
  _globals['_UPLOADTEXTRESPONSE']._serialized_end=687
  _globals['_TALKMETADATA']._serialized_start=690
  _globals['_TALKMETADATA']._serialized_end=845
  _globals['_TALKMETADATA_FIELDSENTRY']._serialized_start=800
  _globals['_TALKMETADATA_FIELDSENTRY']._serialized_end=845
  _globals['_TALKSERVICE']._serialized_start=848
  _globals['_TALKSERVICE']._serialized_end=1196
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/sink.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/logging/v1/sink.proto\x12\x17yandex.cloud.logging.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xfd\x03\n\x04Sink\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x39\n\x06labels\x18\x07 \x03(\x0b\x32).yandex.cloud.logging.v1.Sink.LabelsEntry\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x30\n\x03yds\x18\t \x01(\x0b\x32!.yandex.cloud.logging.v1.Sink.YdsH\x00\x12.\n\x02s3\x18\n \x01(\x0b\x32 .yandex.cloud.logging.v1.Sink.S3H\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a%\n\x03Yds\x12\x1e\n\x0bstream_name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1aT\n\x02S3\x12\x32\n\x06\x62ucket\x18\x01 \x01(\tB\"\xf2\xc7\x31\x1e[a-zA-Z0-9][-a-zA-Z0-9.]{2,62}\x12\x1a\n\x06prefix\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1024B\x0c\n\x04sink\x12\x04\xc0\xc1\x31\x01\x42\x62\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.sink_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _SINK_LABELSENTRY._options = None
  _SINK_LABELSENTRY._serialized_options = b'8\001'
  _SINK_YDS.fields_by_name['stream_name']._options = None
  _SINK_YDS.fields_by_name['stream_name']._serialized_options = b'\212\3101\005<=512'
  _SINK_S3.fields_by_name['bucket']._options = None
  _SINK_S3.fields_by_name['bucket']._serialized_options = b'\362\3071\036[a-zA-Z0-9][-a-zA-Z0-9.]{2,62}'
  _SINK_S3.fields_by_name['prefix']._options = None
  _SINK_S3.fields_by_name['prefix']._serialized_options = b'\212\3101\006<=1024'
  _SINK.oneofs_by_name['sink']._options = None
  _SINK.oneofs_by_name['sink']._serialized_options = b'\300\3011\001'
  _globals['_SINK']._serialized_start=128
  _globals['_SINK']._serialized_end=637
  _globals['_SINK_LABELSENTRY']._serialized_start=453
  _globals['_SINK_LABELSENTRY']._serialized_end=498
  _globals['_SINK_YDS']._serialized_start=500
  _globals['_SINK_YDS']._serialized_end=537
  _globals['_SINK_S3']._serialized_start=539
  _globals['_SINK_S3']._serialized_end=623
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/location_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.ydb.v1 import location_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_location__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/ydb/v1/location_service.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1cgoogle/api/annotations.proto\x1a\"yandex/cloud/ydb/v1/location.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x12GetLocationRequest\x12\x19\n\x0blocation_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"T\n\x14ListLocationsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x15ListLocationsResponse\x12\x30\n\tlocations\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.ydb.v1.Location\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x83\x02\n\x0fLocationService\x12v\n\x03Get\x12\'.yandex.cloud.ydb.v1.GetLocationRequest\x1a\x1d.yandex.cloud.ydb.v1.Location\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/ydb/v1/locations/{location_id}\x12x\n\x04List\x12).yandex.cloud.ydb.v1.ListLocationsRequest\x1a*.yandex.cloud.ydb.v1.ListLocationsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/ydb/v1/locationsBV\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ydb.v1.location_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb'
  _GETLOCATIONREQUEST.fields_by_name['location_id']._options = None
  _GETLOCATIONREQUEST.fields_by_name['location_id']._serialized_options = b'\350\3071\001'
  _LISTLOCATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTLOCATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTLOCATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTLOCATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LOCATIONSERVICE.methods_by_name['Get']._options = None
  _LOCATIONSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/ydb/v1/locations/{location_id}'
  _LOCATIONSERVICE.methods_by_name['List']._options = None
  _LOCATIONSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/ydb/v1/locations'
  _globals['_GETLOCATIONREQUEST']._serialized_start=164
  _globals['_GETLOCATIONREQUEST']._serialized_end=211
  _globals['_LISTLOCATIONSREQUEST']._serialized_start=213
  _globals['_LISTLOCATIONSREQUEST']._serialized_end=297
  _globals['_LISTLOCATIONSRESPONSE']._serialized_start=299
  _globals['_LISTLOCATIONSRESPONSE']._serialized_end=397
  _globals['_LOCATIONSERVICE']._serialized_start=400
  _globals['_LOCATIONSERVICE']._serialized_end=659
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.mdb.kafka.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.kafka.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_maintenance__pb2
from yandex.cloud.mdb.kafka.v1 import topic_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_topic__pb2
from yandex.cloud.mdb.kafka.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_user__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/mdb/kafka/v1/cluster_service.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a\'yandex/cloud/mdb/kafka/v1/cluster.proto\x1a+yandex/cloud/mdb/kafka/v1/maintenance.proto\x1a%yandex/cloud/mdb/kafka/v1/topic.proto\x1a$yandex/cloud/mdb/kafka/v1/user.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x13ListClustersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"e\n\x14ListClustersResponse\x12\x34\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\".yandex.cloud.mdb.kafka.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9f\x06\n\x14\x43reateClusterRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12=\n\x04name\x18\x02 \x01(\tB/\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x04\x31-63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x90\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.mdb.kafka.v1.CreateClusterRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x43\n\x0b\x65nvironment\x18\x05 \x01(\x0e\x32..yandex.cloud.mdb.kafka.v1.Cluster.Environment\x12:\n\x0b\x63onfig_spec\x18\x06 \x01(\x0b\x32%.yandex.cloud.mdb.kafka.v1.ConfigSpec\x12\x39\n\x0btopic_specs\x18\x07 \x03(\x0b\x32$.yandex.cloud.mdb.kafka.v1.TopicSpec\x12\x37\n\nuser_specs\x18\x08 \x03(\x0b\x32#.yandex.cloud.mdb.kafka.v1.UserSpec\x12\x1c\n\nnetwork_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x11\n\tsubnet_id\x18\x0b \x03(\t\x12\x1a\n\x12security_group_ids\x18\x0c \x03(\t\x12\x16\n\x0ehost_group_ids\x18\r \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12H\n\x12maintenance_window\x18\x0f \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.MaintenanceWindow\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\t\x10\n\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xc6\x04\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x88\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.mdb.kafka.v1.UpdateClusterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12:\n\x0b\x63onfig_spec\x18\x05 \x01(\x0b\x32%.yandex.cloud.mdb.kafka.v1.ConfigSpec\x12(\n\x04name\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x12H\n\x12maintenance_window\x18\t \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.MaintenanceWindow\x12\x12\n\nsubnet_ids\x18\x0b \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\n\x10\x0b\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xa7\x02\n\x16ListClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12-\n\tfrom_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\tpage_size\x18\x05 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1e\n\x16\x61lways_next_page_token\x18\x07 \x01(\x08\x12\x1a\n\x06\x66ilter\x18\x08 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xae\x01\n\tLogRecord\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x07message\x18\x02 \x03(\x0b\x32\x31.yandex.cloud.mdb.kafka.v1.LogRecord.MessageEntry\x1a.\n\x0cMessageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x17ListClusterLogsResponse\x12\x32\n\x04logs\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.kafka.v1.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"b\n\x0fStreamLogRecord\x12\x34\n\x06record\x18\x01 \x01(\x0b\x32$.yandex.cloud.mdb.kafka.v1.LogRecord\x12\x19\n\x11next_record_token\x18\x02 \x01(\t\"\xec\x01\n\x18StreamClusterLogsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\rcolumn_filter\x18\x02 \x03(\t\x12-\n\tfrom_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x0crecord_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x06 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"~\n\x1cListClusterOperationsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x17ListClusterHostsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x18ListClusterHostsResponse\x12.\n\x05hosts\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.mdb.kafka.v1.Host\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x12MoveClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x13MoveClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xca\x02\n\x1cRescheduleMaintenanceRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x65\n\x0freschedule_type\x18\x02 \x01(\x0e\x32\x46.yandex.cloud.mdb.kafka.v1.RescheduleMaintenanceRequest.RescheduleTypeB\x04\xe8\xc7\x31\x01\x12\x31\n\rdelayed_until\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x0eRescheduleType\x12\x1f\n\x1bRESCHEDULE_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\"l\n\x1dRescheduleMaintenanceMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x31\n\rdelayed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x04\x32\xa1\x12\n\x0e\x43lusterService\x12\x88\x01\n\x03Get\x12,.yandex.cloud.mdb.kafka.v1.GetClusterRequest\x1a\".yandex.cloud.mdb.kafka.v1.Cluster\"/\x82\xd3\xe4\x93\x02)\x12\'/managed-kafka/v1/clusters/{cluster_id}\x12\x8b\x01\n\x04List\x12..yandex.cloud.mdb.kafka.v1.ListClustersRequest\x1a/.yandex.cloud.mdb.kafka.v1.ListClustersResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/managed-kafka/v1/clusters\x12\xa7\x01\n\x06\x43reate\x12/.yandex.cloud.mdb.kafka.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1f\"\x1a/managed-kafka/v1/clusters:\x01*\x12\xb4\x01\n\x06Update\x12/.yandex.cloud.mdb.kafka.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,2\'/managed-kafka/v1/clusters/{cluster_id}:\x01*\x12\xbf\x01\n\x06\x44\x65lete\x12/.yandex.cloud.mdb.kafka.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/managed-kafka/v1/clusters/{cluster_id}\x12\xb3\x01\n\x04Move\x12-.yandex.cloud.mdb.kafka.v1.MoveClusterRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*\x1e\n\x13MoveClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\",/managed-kafka/v1/clusters/{cluster_id}:move:\x01*\x12\xb4\x01\n\x05Start\x12..yandex.cloud.mdb.kafka.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02/\"-/managed-kafka/v1/clusters/{cluster_id}:start\x12\xb0\x01\n\x04Stop\x12-.yandex.cloud.mdb.kafka.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02.\",/managed-kafka/v1/clusters/{cluster_id}:stop\x12\xe9\x01\n\x15RescheduleMaintenance\x12\x37.yandex.cloud.mdb.kafka.v1.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2*(\n\x1dRescheduleMaintenanceMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x42\"=/managed-kafka/v1/clusters/{cluster_id}:rescheduleMaintenance:\x01*\x12\xa7\x01\n\x08ListLogs\x12\x31.yandex.cloud.mdb.kafka.v1.ListClusterLogsRequest\x1a\x32.yandex.cloud.mdb.kafka.v1.ListClusterLogsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/managed-kafka/v1/clusters/{cluster_id}:logs\x12\xac\x01\n\nStreamLogs\x12\x33.yandex.cloud.mdb.kafka.v1.StreamClusterLogsRequest\x1a*.yandex.cloud.mdb.kafka.v1.StreamLogRecord\";\x82\xd3\xe4\x93\x02\x35\x12\x33/managed-kafka/v1/clusters/{cluster_id}:stream_logs0\x01\x12\xbf\x01\n\x0eListOperations\x12\x37.yandex.cloud.mdb.kafka.v1.ListClusterOperationsRequest\x1a\x38.yandex.cloud.mdb.kafka.v1.ListClusterOperationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-kafka/v1/clusters/{cluster_id}/operations\x12\xab\x01\n\tListHosts\x12\x32.yandex.cloud.mdb.kafka.v1.ListClusterHostsRequest\x1a\x33.yandex.cloud.mdb.kafka.v1.ListClusterHostsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/managed-kafka/v1/clusters/{cluster_id}/hostsBd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATECLUSTERREQUEST_LABELSENTRY._options = None
  _CREATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLUSTERREQUEST.fields_by_name['name']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\0041-63'
  _CREATECLUSTERREQUEST.fields_by_name['description']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATECLUSTERREQUEST_LABELSENTRY._options = None
  _UPDATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LOGRECORD_MESSAGEENTRY._options = None
  _LOGRECORD_MESSAGEENTRY._serialized_options = b'8\001'
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._options = None
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['record_token']._options = None
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['record_token']._serialized_options = b'\212\3101\005<=100'
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['filter']._options = None
  _STREAMCLUSTERLOGSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERHOSTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVECLUSTERREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['cluster_id']._options = None
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type']._options = None
  _RESCHEDULEMAINTENANCEREQUEST.fields_by_name['reschedule_type']._serialized_options = b'\350\3071\001'
  _CLUSTERSERVICE.methods_by_name['Get']._options = None
  _CLUSTERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/managed-kafka/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['List']._options = None
  _CLUSTERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/managed-kafka/v1/clusters'
  _CLUSTERSERVICE.methods_by_name['Create']._options = None
  _CLUSTERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\037\"\032/managed-kafka/v1/clusters:\001*'
  _CLUSTERSERVICE.methods_by_name['Update']._options = None
  _CLUSTERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002,2\'/managed-kafka/v1/clusters/{cluster_id}:\001*'
  _CLUSTERSERVICE.methods_by_name['Delete']._options = None
  _CLUSTERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/managed-kafka/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['Move']._options = None
  _CLUSTERSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveClusterMetadata\022\007Cluster\202\323\344\223\0021\",/managed-kafka/v1/clusters/{cluster_id}:move:\001*'
  _CLUSTERSERVICE.methods_by_name['Start']._options = None
  _CLUSTERSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\002/\"-/managed-kafka/v1/clusters/{cluster_id}:start'
  _CLUSTERSERVICE.methods_by_name['Stop']._options = None
  _CLUSTERSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\002.\",/managed-kafka/v1/clusters/{cluster_id}:stop'
  _CLUSTERSERVICE.methods_by_name['RescheduleMaintenance']._options = None
  _CLUSTERSERVICE.methods_by_name['RescheduleMaintenance']._serialized_options = b'\262\322*(\n\035RescheduleMaintenanceMetadata\022\007Cluster\202\323\344\223\002B\"=/managed-kafka/v1/clusters/{cluster_id}:rescheduleMaintenance:\001*'
  _CLUSTERSERVICE.methods_by_name['ListLogs']._options = None
  _CLUSTERSERVICE.methods_by_name['ListLogs']._serialized_options = b'\202\323\344\223\002.\022,/managed-kafka/v1/clusters/{cluster_id}:logs'
  _CLUSTERSERVICE.methods_by_name['StreamLogs']._options = None
  _CLUSTERSERVICE.methods_by_name['StreamLogs']._serialized_options = b'\202\323\344\223\0025\0223/managed-kafka/v1/clusters/{cluster_id}:stream_logs'
  _CLUSTERSERVICE.methods_by_name['ListOperations']._options = None
  _CLUSTERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0024\0222/managed-kafka/v1/clusters/{cluster_id}/operations'
  _CLUSTERSERVICE.methods_by_name['ListHosts']._options = None
  _CLUSTERSERVICE.methods_by_name['ListHosts']._serialized_options = b'\202\323\344\223\002/\022-/managed-kafka/v1/clusters/{cluster_id}/hosts'
  _globals['_GETCLUSTERREQUEST']._serialized_start=443
  _globals['_GETCLUSTERREQUEST']._serialized_end=496
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=499
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=643
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=645
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=746
  _globals['_CREATECLUSTERREQUEST']._serialized_start=749
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1548
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1497
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1542
  _globals['_CREATECLUSTERMETADATA']._serialized_start=1550
  _globals['_CREATECLUSTERMETADATA']._serialized_end=1593
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1596
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=2178
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1497
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1542
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=2180
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=2223
  _globals['_DELETECLUSTERREQUEST']._serialized_start=2225
  _globals['_DELETECLUSTERREQUEST']._serialized_end=2281
  _globals['_DELETECLUSTERMETADATA']._serialized_start=2283
  _globals['_DELETECLUSTERMETADATA']._serialized_end=2326
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_start=2329
  _globals['_LISTCLUSTERLOGSREQUEST']._serialized_end=2624
  _globals['_LOGRECORD']._serialized_start=2627
  _globals['_LOGRECORD']._serialized_end=2801
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_start=2755
  _globals['_LOGRECORD_MESSAGEENTRY']._serialized_end=2801
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_start=2803
  _globals['_LISTCLUSTERLOGSRESPONSE']._serialized_end=2905
  _globals['_STREAMLOGRECORD']._serialized_start=2907
  _globals['_STREAMLOGRECORD']._serialized_end=3005
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_start=3008
  _globals['_STREAMCLUSTERLOGSREQUEST']._serialized_end=3244
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=3246
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=3372
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=3374
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=3485
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=3487
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=3608
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=3610
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=3709
  _globals['_MOVECLUSTERREQUEST']._serialized_start=3711
  _globals['_MOVECLUSTERREQUEST']._serialized_end=3810
  _globals['_MOVECLUSTERMETADATA']._serialized_start=3812
  _globals['_MOVECLUSTERMETADATA']._serialized_end=3910
  _globals['_STARTCLUSTERREQUEST']._serialized_start=3912
  _globals['_STARTCLUSTERREQUEST']._serialized_end=3967
  _globals['_STARTCLUSTERMETADATA']._serialized_start=3969
  _globals['_STARTCLUSTERMETADATA']._serialized_end=4011
  _globals['_STOPCLUSTERREQUEST']._serialized_start=4013
  _globals['_STOPCLUSTERREQUEST']._serialized_end=4067
  _globals['_STOPCLUSTERMETADATA']._serialized_start=4069
  _globals['_STOPCLUSTERMETADATA']._serialized_end=4110
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=4113
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=4443
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_start=4333
  _globals['_RESCHEDULEMAINTENANCEREQUEST_RESCHEDULETYPE']._serialized_end=4443
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_start=4445
  _globals['_RESCHEDULEMAINTENANCEMETADATA']._serialized_end=4553
  _globals['_CLUSTERSERVICE']._serialized_start=4556
  _globals['_CLUSTERSERVICE']._serialized_end=6893
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/mdb/elasticsearch/v1/user.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1dyandex/cloud/validation.proto\"(\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\"X\n\x08UserSpec\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128B|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _USERSPEC.fields_by_name['name']._options = None
  _USERSPEC.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _USERSPEC.fields_by_name['password']._options = None
  _USERSPEC.fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _globals['_USER']._serialized_start=114
  _globals['_USER']._serialized_end=154
  _globals['_USERSPEC']._serialized_start=156
  _globals['_USERSPEC']._serialized_end=244
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.elasticsearch.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_user__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/elasticsearch/v1/user_service.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/mdb/elasticsearch/v1/user.proto\x1a yandex/cloud/api/operation.proto\"d\n\x0eGetUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\"r\n\x10ListUsersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"d\n\x11ListUsersResponse\x12\x36\n\x05users\x18\x01 \x03(\x0b\x32\'.yandex.cloud.mdb.elasticsearch.v1.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x11\x43reateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x44\n\tuser_spec\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.elasticsearch.v1.UserSpecB\x04\xe8\xc7\x31\x01\";\n\x12\x43reateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xb5\x01\n\x11UpdateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04\x31-63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1b\n\x08password\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x38-128\";\n\x12UpdateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"g\n\x11\x44\x65leteUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04\x31-63\";\n\x12\x44\x65leteUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t2\xe1\x07\n\x0bUserService\x12\xac\x01\n\x03Get\x12\x31.yandex.cloud.mdb.elasticsearch.v1.GetUserRequest\x1a\'.yandex.cloud.mdb.elasticsearch.v1.User\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/managed-elasticsearch/v1/clusters/{cluster_id}/users/{user_name}\x12\xb0\x01\n\x04List\x12\x33.yandex.cloud.mdb.elasticsearch.v1.ListUsersRequest\x1a\x34.yandex.cloud.mdb.elasticsearch.v1.ListUsersResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/managed-elasticsearch/v1/clusters/{cluster_id}/users\x12\xc1\x01\n\x06\x43reate\x12\x34.yandex.cloud.mdb.elasticsearch.v1.CreateUserRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x1a\n\x12\x43reateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02:\"5/managed-elasticsearch/v1/clusters/{cluster_id}/users:\x01*\x12\xcd\x01\n\x06Update\x12\x34.yandex.cloud.mdb.elasticsearch.v1.UpdateUserRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*\x1a\n\x12UpdateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x46\x32\x41/managed-elasticsearch/v1/clusters/{cluster_id}/users/{user_name}:\x01*\x12\xdb\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.mdb.elasticsearch.v1.DeleteUserRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*+\n\x12\x44\x65leteUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43*A/managed-elasticsearch/v1/clusters/{cluster_id}/users/{user_name}B|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.user_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _GETUSERREQUEST.fields_by_name['cluster_id']._options = None
  _GETUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETUSERREQUEST.fields_by_name['user_name']._options = None
  _GETUSERREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _LISTUSERSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTUSERSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTUSERSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTUSERSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEUSERREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEUSERREQUEST.fields_by_name['user_spec']._options = None
  _CREATEUSERREQUEST.fields_by_name['user_spec']._serialized_options = b'\350\3071\001'
  _UPDATEUSERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATEUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEUSERREQUEST.fields_by_name['user_name']._options = None
  _UPDATEUSERREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\0041-63'
  _UPDATEUSERREQUEST.fields_by_name['password']._options = None
  _UPDATEUSERREQUEST.fields_by_name['password']._serialized_options = b'\212\3101\0058-128'
  _DELETEUSERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEUSERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEUSERREQUEST.fields_by_name['user_name']._options = None
  _DELETEUSERREQUEST.fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\0041-63'
  _USERSERVICE.methods_by_name['Get']._options = None
  _USERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002C\022A/managed-elasticsearch/v1/clusters/{cluster_id}/users/{user_name}'
  _USERSERVICE.methods_by_name['List']._options = None
  _USERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\0027\0225/managed-elasticsearch/v1/clusters/{cluster_id}/users'
  _USERSERVICE.methods_by_name['Create']._options = None
  _USERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateUserMetadata\022\004User\202\323\344\223\002:\"5/managed-elasticsearch/v1/clusters/{cluster_id}/users:\001*'
  _USERSERVICE.methods_by_name['Update']._options = None
  _USERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateUserMetadata\022\004User\202\323\344\223\002F2A/managed-elasticsearch/v1/clusters/{cluster_id}/users/{user_name}:\001*'
  _USERSERVICE.methods_by_name['Delete']._options = None
  _USERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteUserMetadata\022\025google.protobuf.Empty\202\323\344\223\002C*A/managed-elasticsearch/v1/clusters/{cluster_id}/users/{user_name}'
  _globals['_GETUSERREQUEST']._serialized_start=306
  _globals['_GETUSERREQUEST']._serialized_end=406
  _globals['_LISTUSERSREQUEST']._serialized_start=408
  _globals['_LISTUSERSREQUEST']._serialized_end=522
  _globals['_LISTUSERSRESPONSE']._serialized_start=524
  _globals['_LISTUSERSRESPONSE']._serialized_end=624
  _globals['_CREATEUSERREQUEST']._serialized_start=626
  _globals['_CREATEUSERREQUEST']._serialized_end=749
  _globals['_CREATEUSERMETADATA']._serialized_start=751
  _globals['_CREATEUSERMETADATA']._serialized_end=810
  _globals['_UPDATEUSERREQUEST']._serialized_start=813
  _globals['_UPDATEUSERREQUEST']._serialized_end=994
  _globals['_UPDATEUSERMETADATA']._serialized_start=996
  _globals['_UPDATEUSERMETADATA']._serialized_end=1055
  _globals['_DELETEUSERREQUEST']._serialized_start=1057
  _globals['_DELETEUSERREQUEST']._serialized_end=1160
  _globals['_DELETEUSERMETADATA']._serialized_start=1162
  _globals['_DELETEUSERMETADATA']._serialized_end=1221
  _globals['_USERSERVICE']._serialized_start=1224
  _globals['_USERSERVICE']._serialized_end=2217
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/stt/v3/stt.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n yandex/cloud/ai/stt/v3/stt.proto\x12\x10speechkit.stt.v3\"\xe2\x03\n\x18TextNormalizationOptions\x12X\n\x12text_normalization\x18\x01 \x01(\x0e\x32<.speechkit.stt.v3.TextNormalizationOptions.TextNormalization\x12\x18\n\x10profanity_filter\x18\x02 \x01(\x08\x12\x17\n\x0fliterature_text\x18\x03 \x01(\x08\x12]\n\x15phone_formatting_mode\x18\x04 \x01(\x0e\x32>.speechkit.stt.v3.TextNormalizationOptions.PhoneFormattingMode\"x\n\x11TextNormalization\x12\"\n\x1eTEXT_NORMALIZATION_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTEXT_NORMALIZATION_ENABLED\x10\x01\x12\x1f\n\x1bTEXT_NORMALIZATION_DISABLED\x10\x02\"`\n\x13PhoneFormattingMode\x12%\n!PHONE_FORMATTING_MODE_UNSPECIFIED\x10\x00\x12\"\n\x1ePHONE_FORMATTING_MODE_DISABLED\x10\x01\"\xce\x01\n\x14\x44\x65\x66\x61ultEouClassifier\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.speechkit.stt.v3.DefaultEouClassifier.EouSensitivity\x12\'\n\x1fmax_pause_between_words_hint_ms\x18\x02 \x01(\x03\"H\n\x0e\x45ouSensitivity\x12\x1f\n\x1b\x45OU_SENSITIVITY_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01\x12\x08\n\x04HIGH\x10\x02\"\x17\n\x15\x45xternalEouClassifier\"\xb2\x01\n\x14\x45ouClassifierOptions\x12\x44\n\x12\x64\x65\x66\x61ult_classifier\x18\x01 \x01(\x0b\x32&.speechkit.stt.v3.DefaultEouClassifierH\x00\x12\x46\n\x13\x65xternal_classifier\x18\x02 \x01(\x0b\x32\'.speechkit.stt.v3.ExternalEouClassifierH\x00\x42\x0c\n\nClassifier\"\xd3\x01\n\x15RecognitionClassifier\x12\x12\n\nclassifier\x18\x01 \x01(\t\x12\x45\n\x08triggers\x18\x02 \x03(\x0e\x32\x33.speechkit.stt.v3.RecognitionClassifier.TriggerType\"_\n\x0bTriggerType\x12 \n\x18TRIGGER_TYPE_UNSPECIFIED\x10\x00\x1a\x02\x08\x01\x12\x10\n\x0cON_UTTERANCE\x10\x01\x12\x0c\n\x08ON_FINAL\x10\x02\x12\x0e\n\nON_PARTIAL\x10\x03\"\\\n\x1cRecognitionClassifierOptions\x12<\n\x0b\x63lassifiers\x18\x01 \x03(\x0b\x32\'.speechkit.stt.v3.RecognitionClassifier\"\x88\x01\n\x15SpeechAnalysisOptions\x12\x1f\n\x17\x65nable_speaker_analysis\x18\x01 \x01(\x08\x12$\n\x1c\x65nable_conversation_analysis\x18\x02 \x01(\x08\x12(\n descriptive_statistics_quantiles\x18\x03 \x03(\x01\"\xc7\x01\n\x08RawAudio\x12@\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32(.speechkit.stt.v3.RawAudio.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x03\x12\x1b\n\x13\x61udio_channel_count\x18\x03 \x01(\x03\"A\n\rAudioEncoding\x12\x1e\n\x1a\x41UDIO_ENCODING_UNSPECIFIED\x10\x00\x12\x10\n\x0cLINEAR16_PCM\x10\x01\"\xbf\x01\n\x0e\x43ontainerAudio\x12Q\n\x14\x63ontainer_audio_type\x18\x01 \x01(\x0e\x32\x33.speechkit.stt.v3.ContainerAudio.ContainerAudioType\"Z\n\x12\x43ontainerAudioType\x12$\n CONTAINER_AUDIO_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03WAV\x10\x01\x12\x0c\n\x08OGG_OPUS\x10\x02\x12\x07\n\x03MP3\x10\x03\"\x91\x01\n\x12\x41udioFormatOptions\x12/\n\traw_audio\x18\x01 \x01(\x0b\x32\x1a.speechkit.stt.v3.RawAudioH\x00\x12;\n\x0f\x63ontainer_audio\x18\x02 \x01(\x0b\x32 .speechkit.stt.v3.ContainerAudioH\x00\x42\r\n\x0b\x41udioFormat\"\xf7\x01\n\x1aLanguageRestrictionOptions\x12^\n\x10restriction_type\x18\x01 \x01(\x0e\x32\x44.speechkit.stt.v3.LanguageRestrictionOptions.LanguageRestrictionType\x12\x15\n\rlanguage_code\x18\x02 \x03(\t\"b\n\x17LanguageRestrictionType\x12)\n%LANGUAGE_RESTRICTION_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tWHITELIST\x10\x01\x12\r\n\tBLACKLIST\x10\x02\"\xb2\x03\n\x17RecognitionModelOptions\x12\r\n\x05model\x18\x01 \x01(\t\x12:\n\x0c\x61udio_format\x18\x02 \x01(\x0b\x32$.speechkit.stt.v3.AudioFormatOptions\x12\x46\n\x12text_normalization\x18\x03 \x01(\x0b\x32*.speechkit.stt.v3.TextNormalizationOptions\x12J\n\x14language_restriction\x18\x04 \x01(\x0b\x32,.speechkit.stt.v3.LanguageRestrictionOptions\x12\\\n\x15\x61udio_processing_type\x18\x05 \x01(\x0e\x32=.speechkit.stt.v3.RecognitionModelOptions.AudioProcessingType\"Z\n\x13\x41udioProcessingType\x12%\n!AUDIO_PROCESSING_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tREAL_TIME\x10\x01\x12\r\n\tFULL_DATA\x10\x02\"\xde\x01\n\x16SpeakerLabelingOptions\x12R\n\x10speaker_labeling\x18\x01 \x01(\x0e\x32\x38.speechkit.stt.v3.SpeakerLabelingOptions.SpeakerLabeling\"p\n\x0fSpeakerLabeling\x12 \n\x1cSPEAKER_LABELING_UNSPECIFIED\x10\x00\x12\x1c\n\x18SPEAKER_LABELING_ENABLED\x10\x01\x12\x1d\n\x19SPEAKER_LABELING_DISABLED\x10\x02\"\xee\x02\n\x10StreamingOptions\x12\x44\n\x11recognition_model\x18\x01 \x01(\x0b\x32).speechkit.stt.v3.RecognitionModelOptions\x12>\n\x0e\x65ou_classifier\x18\x02 \x01(\x0b\x32&.speechkit.stt.v3.EouClassifierOptions\x12N\n\x16recognition_classifier\x18\x03 \x01(\x0b\x32..speechkit.stt.v3.RecognitionClassifierOptions\x12@\n\x0fspeech_analysis\x18\x04 \x01(\x0b\x32\'.speechkit.stt.v3.SpeechAnalysisOptions\x12\x42\n\x10speaker_labeling\x18\x05 \x01(\x0b\x32(.speechkit.stt.v3.SpeakerLabelingOptions\"\x1a\n\nAudioChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"#\n\x0cSilenceChunk\x12\x13\n\x0b\x64uration_ms\x18\x01 \x01(\x03\"\x05\n\x03\x45ou\"\xe8\x01\n\x10StreamingRequest\x12=\n\x0fsession_options\x18\x01 \x01(\x0b\x32\".speechkit.stt.v3.StreamingOptionsH\x00\x12-\n\x05\x63hunk\x18\x02 \x01(\x0b\x32\x1c.speechkit.stt.v3.AudioChunkH\x00\x12\x37\n\rsilence_chunk\x18\x03 \x01(\x0b\x32\x1e.speechkit.stt.v3.SilenceChunkH\x00\x12$\n\x03\x65ou\x18\x04 \x01(\x0b\x32\x15.speechkit.stt.v3.EouH\x00\x42\x07\n\x05\x45vent\"\xe3\x02\n\x14RecognizeFileRequest\x12\x11\n\x07\x63ontent\x18\x01 \x01(\x0cH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x12\x44\n\x11recognition_model\x18\x03 \x01(\x0b\x32).speechkit.stt.v3.RecognitionModelOptions\x12N\n\x16recognition_classifier\x18\x04 \x01(\x0b\x32..speechkit.stt.v3.RecognitionClassifierOptions\x12@\n\x0fspeech_analysis\x18\x05 \x01(\x0b\x32\'.speechkit.stt.v3.SpeechAnalysisOptions\x12\x42\n\x10speaker_labeling\x18\x06 \x01(\x0b\x32(.speechkit.stt.v3.SpeakerLabelingOptionsB\r\n\x0b\x41udioSource\"@\n\x04Word\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\rstart_time_ms\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x03 \x01(\x03\"@\n\x12LanguageEstimation\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\x13\n\x0bprobability\x18\x02 \x01(\x01\"\xbb\x01\n\x0b\x41lternative\x12%\n\x05words\x18\x01 \x03(\x0b\x32\x16.speechkit.stt.v3.Word\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x15\n\rstart_time_ms\x18\x03 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x04 \x01(\x03\x12\x12\n\nconfidence\x18\x05 \x01(\x01\x12\x37\n\tlanguages\x18\x06 \x03(\x0b\x32$.speechkit.stt.v3.LanguageEstimation\"\x1c\n\tEouUpdate\x12\x0f\n\x07time_ms\x18\x02 \x01(\x03\"a\n\x11\x41lternativeUpdate\x12\x33\n\x0c\x61lternatives\x18\x01 \x03(\x0b\x32\x1d.speechkit.stt.v3.Alternative\x12\x17\n\x0b\x63hannel_tag\x18\x02 \x01(\tB\x02\x18\x01\"\x99\x01\n\x0c\x41udioCursors\x12\x18\n\x10received_data_ms\x18\x01 \x01(\x03\x12\x15\n\rreset_time_ms\x18\x02 \x01(\x03\x12\x17\n\x0fpartial_time_ms\x18\x03 \x01(\x03\x12\x15\n\rfinal_time_ms\x18\x04 \x01(\x03\x12\x13\n\x0b\x66inal_index\x18\x05 \x01(\x03\x12\x13\n\x0b\x65ou_time_ms\x18\x06 \x01(\x03\"n\n\x0f\x46inalRefinement\x12\x13\n\x0b\x66inal_index\x18\x01 \x01(\x03\x12>\n\x0fnormalized_text\x18\x02 \x01(\x0b\x32#.speechkit.stt.v3.AlternativeUpdateH\x00\x42\x06\n\x04Type\"L\n\nStatusCode\x12-\n\tcode_type\x18\x01 \x01(\x0e\x32\x1a.speechkit.stt.v3.CodeType\x12\x0f\n\x07message\x18\x02 \x01(\t\"4\n\x0bSessionUuid\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x17\n\x0fuser_request_id\x18\x02 \x01(\t\"K\n\x0fPhraseHighlight\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\rstart_time_ms\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x03 \x01(\x03\"?\n\x1aRecognitionClassifierLabel\x12\r\n\x05label\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x01\"\xa6\x01\n\x1bRecognitionClassifierResult\x12\x12\n\nclassifier\x18\x01 \x01(\t\x12\x35\n\nhighlights\x18\x02 \x03(\x0b\x32!.speechkit.stt.v3.PhraseHighlight\x12<\n\x06labels\x18\x03 \x03(\x0b\x32,.speechkit.stt.v3.RecognitionClassifierLabel\"\xc7\x02\n\x1bRecognitionClassifierUpdate\x12M\n\x0bwindow_type\x18\x01 \x01(\x0e\x32\x38.speechkit.stt.v3.RecognitionClassifierUpdate.WindowType\x12\x15\n\rstart_time_ms\x18\x02 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x03 \x01(\x03\x12H\n\x11\x63lassifier_result\x18\x04 \x01(\x0b\x32-.speechkit.stt.v3.RecognitionClassifierResult\"c\n\nWindowType\x12\x1f\n\x17WINDOW_TYPE_UNSPECIFIED\x10\x00\x1a\x02\x08\x01\x12\x12\n\x0eLAST_UTTERANCE\x10\x01\x12\x0e\n\nLAST_FINAL\x10\x02\x12\x10\n\x0cLAST_PARTIAL\x10\x03\"\xbb\x01\n\x15\x44\x65scriptiveStatistics\x12\x0b\n\x03min\x18\x01 \x01(\x01\x12\x0b\n\x03max\x18\x02 \x01(\x01\x12\x0c\n\x04mean\x18\x03 \x01(\x01\x12\x0b\n\x03std\x18\x04 \x01(\x01\x12\x43\n\tquantiles\x18\x05 \x03(\x0b\x32\x30.speechkit.stt.v3.DescriptiveStatistics.Quantile\x1a(\n\x08Quantile\x12\r\n\x05level\x18\x01 \x01(\x01\x12\r\n\x05value\x18\x02 \x01(\x01\"D\n\x16\x41udioSegmentBoundaries\x12\x15\n\rstart_time_ms\x18\x01 \x01(\x03\x12\x13\n\x0b\x65nd_time_ms\x18\x02 \x01(\x03\"\x87\x06\n\x0fSpeakerAnalysis\x12\x13\n\x0bspeaker_tag\x18\x01 \x01(\t\x12\x41\n\x0bwindow_type\x18\x02 \x01(\x0e\x32,.speechkit.stt.v3.SpeakerAnalysis.WindowType\x12\x43\n\x11speech_boundaries\x18\x03 \x01(\x0b\x32(.speechkit.stt.v3.AudioSegmentBoundaries\x12\x17\n\x0ftotal_speech_ms\x18\x04 \x01(\x03\x12\x14\n\x0cspeech_ratio\x18\x05 \x01(\x01\x12\x18\n\x10total_silence_ms\x18\x06 \x01(\x03\x12\x15\n\rsilence_ratio\x18\x07 \x01(\x01\x12\x13\n\x0bwords_count\x18\x08 \x01(\x03\x12\x15\n\rletters_count\x18\t \x01(\x03\x12\x41\n\x10words_per_second\x18\n \x01(\x0b\x32\'.speechkit.stt.v3.DescriptiveStatistics\x12\x43\n\x12letters_per_second\x18\x0b \x01(\x0b\x32\'.speechkit.stt.v3.DescriptiveStatistics\x12\x44\n\x13words_per_utterance\x18\x0c \x01(\x0b\x32\'.speechkit.stt.v3.DescriptiveStatistics\x12\x46\n\x15letters_per_utterance\x18\r \x01(\x0b\x32\'.speechkit.stt.v3.DescriptiveStatistics\x12\x17\n\x0futterance_count\x18\x0e \x01(\x03\x12N\n\x1dutterance_duration_estimation\x18\x0f \x01(\x0b\x32\'.speechkit.stt.v3.DescriptiveStatistics\"L\n\nWindowType\x12\x1f\n\x17WINDOW_TYPE_UNSPECIFIED\x10\x00\x1a\x02\x08\x01\x12\t\n\x05TOTAL\x10\x01\x12\x12\n\x0eLAST_UTTERANCE\x10\x02\"\x85\x06\n\x14\x43onversationAnalysis\x12I\n\x17\x63onversation_boundaries\x18\x01 \x01(\x0b\x32(.speechkit.stt.v3.AudioSegmentBoundaries\x12.\n&total_simultaneous_silence_duration_ms\x18\x02 \x01(\x03\x12(\n total_simultaneous_silence_ratio\x18\x03 \x01(\x01\x12Y\n(simultaneous_silence_duration_estimation\x18\x04 \x01(\x0b\x32\'.speechkit.stt.v3.DescriptiveStatistics\x12-\n%total_simultaneous_speech_duration_ms\x18\x05 \x01(\x03\x12\'\n\x1ftotal_simultaneous_speech_ratio\x18\x06 \x01(\x01\x12X\n\'simultaneous_speech_duration_estimation\x18\x07 \x01(\x0b\x32\'.speechkit.stt.v3.DescriptiveStatistics\x12W\n\x12speaker_interrupts\x18\x08 \x03(\x0b\x32;.speechkit.stt.v3.ConversationAnalysis.InterruptsEvaluation\x12 \n\x18total_speech_duration_ms\x18\t \x01(\x03\x12\x1a\n\x12total_speech_ratio\x18\n \x01(\x01\x1a\xa3\x01\n\x14InterruptsEvaluation\x12\x13\n\x0bspeaker_tag\x18\x01 \x01(\t\x12\x18\n\x10interrupts_count\x18\x02 \x01(\x03\x12\x1e\n\x16interrupts_duration_ms\x18\x03 \x01(\x03\x12<\n\ninterrupts\x18\x04 \x03(\x0b\x32(.speechkit.stt.v3.AudioSegmentBoundaries\"\xa5\x05\n\x11StreamingResponse\x12\x33\n\x0csession_uuid\x18\x01 \x01(\x0b\x32\x1d.speechkit.stt.v3.SessionUuid\x12\x35\n\raudio_cursors\x18\x02 \x01(\x0b\x32\x1e.speechkit.stt.v3.AudioCursors\x12\x1d\n\x15response_wall_time_ms\x18\x03 \x01(\x03\x12\x36\n\x07partial\x18\x04 \x01(\x0b\x32#.speechkit.stt.v3.AlternativeUpdateH\x00\x12\x34\n\x05\x66inal\x18\x05 \x01(\x0b\x32#.speechkit.stt.v3.AlternativeUpdateH\x00\x12\x31\n\neou_update\x18\x06 \x01(\x0b\x32\x1b.speechkit.stt.v3.EouUpdateH\x00\x12=\n\x10\x66inal_refinement\x18\x07 \x01(\x0b\x32!.speechkit.stt.v3.FinalRefinementH\x00\x12\x33\n\x0bstatus_code\x18\x08 \x01(\x0b\x32\x1c.speechkit.stt.v3.StatusCodeH\x00\x12J\n\x11\x63lassifier_update\x18\n \x01(\x0b\x32-.speechkit.stt.v3.RecognitionClassifierUpdateH\x00\x12=\n\x10speaker_analysis\x18\x0b \x01(\x0b\x32!.speechkit.stt.v3.SpeakerAnalysisH\x00\x12G\n\x15\x63onversation_analysis\x18\x0c \x01(\x0b\x32&.speechkit.stt.v3.ConversationAnalysisH\x00\x12\x13\n\x0b\x63hannel_tag\x18\t \x01(\tB\x07\n\x05\x45vent*O\n\x08\x43odeType\x12\x1d\n\x15\x43ODE_TYPE_UNSPECIFIED\x10\x00\x1a\x02\x08\x01\x12\x0b\n\x07WORKING\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\n\n\x06\x43LOSED\x10\x03\x42\\\n\x1ayandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;sttb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.stt.v3.stt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.ai.stt.v3Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v3;stt'
  _CODETYPE.values_by_name["CODE_TYPE_UNSPECIFIED"]._options = None
  _CODETYPE.values_by_name["CODE_TYPE_UNSPECIFIED"]._serialized_options = b'\010\001'
  _RECOGNITIONCLASSIFIER_TRIGGERTYPE.values_by_name["TRIGGER_TYPE_UNSPECIFIED"]._options = None
  _RECOGNITIONCLASSIFIER_TRIGGERTYPE.values_by_name["TRIGGER_TYPE_UNSPECIFIED"]._serialized_options = b'\010\001'
  _ALTERNATIVEUPDATE.fields_by_name['channel_tag']._options = None
  _ALTERNATIVEUPDATE.fields_by_name['channel_tag']._serialized_options = b'\030\001'
  _RECOGNITIONCLASSIFIERUPDATE_WINDOWTYPE.values_by_name["WINDOW_TYPE_UNSPECIFIED"]._options = None
  _RECOGNITIONCLASSIFIERUPDATE_WINDOWTYPE.values_by_name["WINDOW_TYPE_UNSPECIFIED"]._serialized_options = b'\010\001'
  _SPEAKERANALYSIS_WINDOWTYPE.values_by_name["WINDOW_TYPE_UNSPECIFIED"]._options = None
  _SPEAKERANALYSIS_WINDOWTYPE.values_by_name["WINDOW_TYPE_UNSPECIFIED"]._serialized_options = b'\010\001'
  _globals['_CODETYPE']._serialized_start=7877
  _globals['_CODETYPE']._serialized_end=7956
  _globals['_TEXTNORMALIZATIONOPTIONS']._serialized_start=55
  _globals['_TEXTNORMALIZATIONOPTIONS']._serialized_end=537
  _globals['_TEXTNORMALIZATIONOPTIONS_TEXTNORMALIZATION']._serialized_start=319
  _globals['_TEXTNORMALIZATIONOPTIONS_TEXTNORMALIZATION']._serialized_end=439
  _globals['_TEXTNORMALIZATIONOPTIONS_PHONEFORMATTINGMODE']._serialized_start=441
  _globals['_TEXTNORMALIZATIONOPTIONS_PHONEFORMATTINGMODE']._serialized_end=537
  _globals['_DEFAULTEOUCLASSIFIER']._serialized_start=540
  _globals['_DEFAULTEOUCLASSIFIER']._serialized_end=746
  _globals['_DEFAULTEOUCLASSIFIER_EOUSENSITIVITY']._serialized_start=674
  _globals['_DEFAULTEOUCLASSIFIER_EOUSENSITIVITY']._serialized_end=746
  _globals['_EXTERNALEOUCLASSIFIER']._serialized_start=748
  _globals['_EXTERNALEOUCLASSIFIER']._serialized_end=771
  _globals['_EOUCLASSIFIEROPTIONS']._serialized_start=774
  _globals['_EOUCLASSIFIEROPTIONS']._serialized_end=952
  _globals['_RECOGNITIONCLASSIFIER']._serialized_start=955
  _globals['_RECOGNITIONCLASSIFIER']._serialized_end=1166
  _globals['_RECOGNITIONCLASSIFIER_TRIGGERTYPE']._serialized_start=1071
  _globals['_RECOGNITIONCLASSIFIER_TRIGGERTYPE']._serialized_end=1166
  _globals['_RECOGNITIONCLASSIFIEROPTIONS']._serialized_start=1168
  _globals['_RECOGNITIONCLASSIFIEROPTIONS']._serialized_end=1260
  _globals['_SPEECHANALYSISOPTIONS']._serialized_start=1263
  _globals['_SPEECHANALYSISOPTIONS']._serialized_end=1399
  _globals['_RAWAUDIO']._serialized_start=1402
  _globals['_RAWAUDIO']._serialized_end=1601
  _globals['_RAWAUDIO_AUDIOENCODING']._serialized_start=1536
  _globals['_RAWAUDIO_AUDIOENCODING']._serialized_end=1601
  _globals['_CONTAINERAUDIO']._serialized_start=1604
  _globals['_CONTAINERAUDIO']._serialized_end=1795
  _globals['_CONTAINERAUDIO_CONTAINERAUDIOTYPE']._serialized_start=1705
  _globals['_CONTAINERAUDIO_CONTAINERAUDIOTYPE']._serialized_end=1795
  _globals['_AUDIOFORMATOPTIONS']._serialized_start=1798
  _globals['_AUDIOFORMATOPTIONS']._serialized_end=1943
  _globals['_LANGUAGERESTRICTIONOPTIONS']._serialized_start=1946
  _globals['_LANGUAGERESTRICTIONOPTIONS']._serialized_end=2193
  _globals['_LANGUAGERESTRICTIONOPTIONS_LANGUAGERESTRICTIONTYPE']._serialized_start=2095
  _globals['_LANGUAGERESTRICTIONOPTIONS_LANGUAGERESTRICTIONTYPE']._serialized_end=2193
  _globals['_RECOGNITIONMODELOPTIONS']._serialized_start=2196
  _globals['_RECOGNITIONMODELOPTIONS']._serialized_end=2630
  _globals['_RECOGNITIONMODELOPTIONS_AUDIOPROCESSINGTYPE']._serialized_start=2540
  _globals['_RECOGNITIONMODELOPTIONS_AUDIOPROCESSINGTYPE']._serialized_end=2630
  _globals['_SPEAKERLABELINGOPTIONS']._serialized_start=2633
  _globals['_SPEAKERLABELINGOPTIONS']._serialized_end=2855
  _globals['_SPEAKERLABELINGOPTIONS_SPEAKERLABELING']._serialized_start=2743
  _globals['_SPEAKERLABELINGOPTIONS_SPEAKERLABELING']._serialized_end=2855
  _globals['_STREAMINGOPTIONS']._serialized_start=2858
  _globals['_STREAMINGOPTIONS']._serialized_end=3224
  _globals['_AUDIOCHUNK']._serialized_start=3226
  _globals['_AUDIOCHUNK']._serialized_end=3252
  _globals['_SILENCECHUNK']._serialized_start=3254
  _globals['_SILENCECHUNK']._serialized_end=3289
  _globals['_EOU']._serialized_start=3291
  _globals['_EOU']._serialized_end=3296
  _globals['_STREAMINGREQUEST']._serialized_start=3299
  _globals['_STREAMINGREQUEST']._serialized_end=3531
  _globals['_RECOGNIZEFILEREQUEST']._serialized_start=3534
  _globals['_RECOGNIZEFILEREQUEST']._serialized_end=3889
  _globals['_WORD']._serialized_start=3891
  _globals['_WORD']._serialized_end=3955
  _globals['_LANGUAGEESTIMATION']._serialized_start=3957
  _globals['_LANGUAGEESTIMATION']._serialized_end=4021
  _globals['_ALTERNATIVE']._serialized_start=4024
  _globals['_ALTERNATIVE']._serialized_end=4211
  _globals['_EOUUPDATE']._serialized_start=4213
  _globals['_EOUUPDATE']._serialized_end=4241
  _globals['_ALTERNATIVEUPDATE']._serialized_start=4243
  _globals['_ALTERNATIVEUPDATE']._serialized_end=4340
  _globals['_AUDIOCURSORS']._serialized_start=4343
  _globals['_AUDIOCURSORS']._serialized_end=4496
  _globals['_FINALREFINEMENT']._serialized_start=4498
  _globals['_FINALREFINEMENT']._serialized_end=4608
  _globals['_STATUSCODE']._serialized_start=4610
  _globals['_STATUSCODE']._serialized_end=4686
  _globals['_SESSIONUUID']._serialized_start=4688
  _globals['_SESSIONUUID']._serialized_end=4740
  _globals['_PHRASEHIGHLIGHT']._serialized_start=4742
  _globals['_PHRASEHIGHLIGHT']._serialized_end=4817
  _globals['_RECOGNITIONCLASSIFIERLABEL']._serialized_start=4819
  _globals['_RECOGNITIONCLASSIFIERLABEL']._serialized_end=4882
  _globals['_RECOGNITIONCLASSIFIERRESULT']._serialized_start=4885
  _globals['_RECOGNITIONCLASSIFIERRESULT']._serialized_end=5051
  _globals['_RECOGNITIONCLASSIFIERUPDATE']._serialized_start=5054
  _globals['_RECOGNITIONCLASSIFIERUPDATE']._serialized_end=5381
  _globals['_RECOGNITIONCLASSIFIERUPDATE_WINDOWTYPE']._serialized_start=5282
  _globals['_RECOGNITIONCLASSIFIERUPDATE_WINDOWTYPE']._serialized_end=5381
  _globals['_DESCRIPTIVESTATISTICS']._serialized_start=5384
  _globals['_DESCRIPTIVESTATISTICS']._serialized_end=5571
  _globals['_DESCRIPTIVESTATISTICS_QUANTILE']._serialized_start=5531
  _globals['_DESCRIPTIVESTATISTICS_QUANTILE']._serialized_end=5571
  _globals['_AUDIOSEGMENTBOUNDARIES']._serialized_start=5573
  _globals['_AUDIOSEGMENTBOUNDARIES']._serialized_end=5641
  _globals['_SPEAKERANALYSIS']._serialized_start=5644
  _globals['_SPEAKERANALYSIS']._serialized_end=6419
  _globals['_SPEAKERANALYSIS_WINDOWTYPE']._serialized_start=6343
  _globals['_SPEAKERANALYSIS_WINDOWTYPE']._serialized_end=6419
  _globals['_CONVERSATIONANALYSIS']._serialized_start=6422
  _globals['_CONVERSATIONANALYSIS']._serialized_end=7195
  _globals['_CONVERSATIONANALYSIS_INTERRUPTSEVALUATION']._serialized_start=7032
  _globals['_CONVERSATIONANALYSIS_INTERRUPTSEVALUATION']._serialized_end=7195
  _globals['_STREAMINGRESPONSE']._serialized_start=7198
  _globals['_STREAMINGRESPONSE']._serialized_end=7875
# @@protoc_insertion_point(module_scope)
